@@ -47,8 +47,8 @@ class NxPyDocs():
             for single_command in self.supported_templates:
                 self.command = single_command
                 command_output = clid( '%s' % self.command )
-                parsed_json = json.loads(command_output, indent=4, sort_keys=True)
-                pp.pprint(parsed_json)
+                parsed_json = json.loads(command_output)
+                pp.pprint(json.dumps(parsed_json))
                 if "Cannot" in parsed_json:
                     click.secho("No Data To Create File", fg='red')
                 else:
@@ -57,8 +57,8 @@ class NxPyDocs():
         else:
             if self.command in self.supported_templates:
                 command_output = clid( '%s' % self.command )
-                parsed_json = json.loads(command_output, indent=4, sort_keys=True)
-                pp.pprint(parsed_json)
+                parsed_json = json.loads(command_output)
+                pp.pprint(json.dumps(parsed_json))
                 if "Cannot" in parsed_json:
                     click.secho("No Data To Create File", fg='red')
                 else:
@@ -86,12 +86,12 @@ class NxPyDocs():
 
     def json_file(self, parsed_json):
         with open(' %s.json' % self.command, 'w') as f:
-            f.write(parsed_json)
+            f.write(json.dumps(parsed_json))
         click.secho("JSON file created at %s / %s.json" % (sys.path[0],self.command),
         fg='green')
 
     def yaml_file(self, parsed_json):
-        clean_yaml = yaml.dump(json.loads(parsed_json), default_flow_style=False)
+        clean_yaml = yaml.dump(json.loads(json.dumps(parsed_json)), default_flow_style=False)
         with open(' %s.yaml' % self.command, 'w') as f:
             f.write(clean_yaml)
         click.secho("YAML file created at %s / %s.yaml" % (sys.path[0],self.command),
